@@ -13,7 +13,7 @@ use Email::MIME::CreateHTML;
 use Email::Sender::Simple 'sendmail';
 use MIME::Words 'encode_mimewords';
 
-our $VERSION = '1.12'; # VERSION
+our $VERSION = '1.13'; # VERSION
 
 sub new {
     my $self = shift;
@@ -59,16 +59,17 @@ sub send {
                 ->format( HTML::TreeBuilder->new->parse( $mail->{html} ) );
         }
 
-        my @keys = keys %$mail;
-        for my $name ( qw( to from subject ) ) {
-            my ($key) = grep { lc($_) eq $name } @keys;
-            $mail->{$key} = encode_mimewords( $mail->{$key} )
-                if ( $key and defined $mail->{$key} and $mail->{$key} =~ /[^[:ascii:]]/ );
-        }
-
         $mail->{'Content-Transfer-Encoding'} //= 'quoted-printable';
         $mail->{'Content-Type'}              ||= 'text/plain; charset=us-ascii';
 
+        my $charset = ( $mail->{'Content-Type'} =~ /\bcharset\s*=\s*([^;]+)/i ) ? $1 : 'ISO-8859-1';
+        my @keys    = keys %$mail;
+        for my $name ( qw( to from subject ) ) {
+            my ($key) = grep { lc($_) eq $name } @keys;
+            $mail->{$key} = encode_mimewords( $mail->{$key}, Charset => $charset )
+                if ( $key and defined $mail->{$key} and $mail->{$key} =~ /[^[:ascii:]]/ );
+        }
+
         # create a headers hashref (delete things from a data copy that known to not be headers)
         my $headers = [
             map {
@@ -157,7 +158,7 @@ Email::Mailer - Multi-purpose emailer for HTML, auto-text, attachments, and temp
 
 =head1 VERSION
 
-version 1.12
+version 1.13
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Email-Mailer.svg)](https://travis-ci.org/gryphonshafer/Email-Mailer)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Email-Mailer/badge.png)](https://coveralls.io/r/gryphonshafer/Email-Mailer)
@@ -498,8 +499,9 @@ if you set the following:
 
 Also, normally your C<to>, C<from>, and C<subject> values are left untouched;
 however, for any of these that contain non-ASCII characters, they will be
-mimewords-encoded via L<MIME::Words>. If you don't like how that works, just
-encode them however you'd like to ASCII.
+mimewords-encoded via L<MIME::Words> using the character set defined in
+C<Content-Type>. If you don't like how that works, just encode them however
+you'd like to ASCII.
 
 =head1 SEE ALSO
 
